<template>
  <div>
    <el-dialog :visible.sync="dialogVisible" :title="title" :close-on-click-modal="false"
               :modal-append-to-body="false" v-if="dialogVisible" width="40%">
      <el-form size="mini" :model="form" label-width="120px" ref="form" :rules="formRules">
        <el-form-item label="分类名称：" prop="catName">
          <el-input v-model="form.catName" placeholder="请输入分类名称" clearable></el-input>
        </el-form-item>
        <el-form-item label="排序值：" prop="catIndexNum">
          <el-input-number v-model="form.catIndexNum" @keydown.native="limiInputType" :min="1">
          </el-input-number>
        </el-form-item>
        <el-form-item label="分类描述：" prop="catDesc">
          <el-input v-model="form.catDesc" type="textarea" :autosize="{minRows:2,maxRows:4}"
                    placeholder="请输入分类描述" clearable></el-input>
        </el-form-item>
        <el-form-item label="分类图标：">
          <upload-img :limitNumber="1" :isAppendTobody="true" @handle-success="handleSuccess"
                      @handle-remove="handleRemove" :fileList="fileList"></upload-img>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button size="mini" @click="submit" type="primary" :loading="loading">保存</el-button>
        <el-button size="mini" @click="dialogVisible = false">取消</el-button>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import productExhibitionApi from '@/api/productmanagement/productExhibition'
import { getStrLength } from '@/utils/getStrLength'
import { limiInputType } from '@/utils/limiInputType'
export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    title: {
      type: String,
      default: '添加品牌'
    },
    row: {
      type: Object,
      default: function () {
        return {}
      }
    }
  },
  data () {
    return {
      dialogVisible: false,
      form: {
        bizId: 'B02',
        catName: null,
        catIndexNum: 1,
        catDesc: null,
        catImg: null,
        parentCatId: null
      },
      formRules: {
        catName: [
          { required: true, message: '请输入分类名称', trigger: 'change' },
          {
            validator: (rule, value, callback) => {
              callback(getStrLength(rule, value, callback, 100, '分类名称'))
            }
          }
        ],
        catIndexNum: [{ required: true, message: '请输入排序值', trigger: 'change' }],
        catDesc: {
          validator: (rule, value, callback) => {
            callback(getStrLength(rule, value, callback, 2000, '分类描述'))
          }
        }
      },
      loading: false,
      fileList: [] // 图片数组集合
    }
  },
  watch: {
    /**
     * 监控外部显示变量变化
     * 传递到dialog组件
     */
    show: function (newShow, oldShow) {
      this.dialogVisible = newShow
      if (this.dialogVisible) {
        this.fileList = []
        if (this.row.catId) {
          this.form = this.row
          if (this.form.catImg) {
            this.fileList.push({
              url: this.form.catImg
            })
          }
        } else if (this.row.parentCatId) {
          this.form.parentCatId = this.row.parentCatId
        }
      }
    },
    /**
     * 监控内部显示属性变化
     * 传递到外部调用变量
     */
    dialogVisible: function (newDialogShow, oldDialogShow) {
      if (!newDialogShow) {
        for (const i in this.form) {
          this.form[i] = null
        }
        this.fileList = []
        this.$emit('update:show', newDialogShow)
      }
    }
  },
  methods: {
    /**
     * 限制不能输入数字
     */
    limiInputType (e) {
      limiInputType(e)
    },
    /**
     * 获取上传成功的图片
     */
    handleSuccess (data) {
      this.form.catImg = data.like
    },
    /**
     * 移除图片
     */
    handleRemove (data) {
      this.form.catImg = ''
    },
    /**
       * 提交
       */
    submit () {
      this.$refs.form.validate().then(res => {
        this.loading = true
        let resDate = null
        this.form.bizId = 'B02'
        if (this.form.catId) {
          resDate = productExhibitionApi.updateInfo(this.form)
        } else {
          resDate = productExhibitionApi.addInfo(this.form)
        }
        resDate.then(res => {
          if (res.data) {
            this.$message({
              message: '操作成功',
              type: 'success'
            })
            this.loading = false
            this.$emit('hand-refresh-tree-data')
            this.dialogVisible = false
          } else {
            this.loading = false
          }
        }).catch(() => {
          this.loading = false
        })
      })
    }
  }
}
</script>
